@@ -1,5 +1,3 @@
-use std::process;
-
 use rocket::response::Redirect;
 use rocket::State;
 
@@ -19,13 +17,12 @@ fn query(q: &str, shortcuts: &State<shortcut::ShortcutRegistry>) -> Redirect {
 #[launch]
 fn rocket() -> _ {
     let app_config = config::get_config();
-    let registry = shortcut::ShortcutRegistry::new(app_config);
 
-    let registry = match registry {
+    let registry = match shortcut::ShortcutRegistry::new(app_config) {
         Ok(registry) => registry,
         Err(e) => {
-            eprintln!("{}", e);
-            process::exit(1);
+            eprintln!("{}.", e);
+            std::process::exit(1);
         }
     };
 
